@@ -15,7 +15,6 @@
 # Purpose  : Provides location to maintain version information.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
-
 # This file was created with a width of 132 characters, and NO tabs.
 
 
@@ -35,7 +34,7 @@ Provides location to maintain version information.
 # Version information
 ########################################################################
 
-VERSION     = "0.7.1"
-DATE        = "16 Jul 2003"
+VERSION     = "0.7.2"
+DATE        = "09 Sep 2003"
 
 
